Security Policy
===============


Reporting a Vulnerability
-------------------------

If you discover a security vulnerability within ``django-environ``, please
send an e-mail to Daniele Faraglia via daniele.faraglia+oss@gmail.com. All security
vulnerabilities will be promptly addressed.
